<?php
// +----------------------------------------------------------------------+
// | Anuko Time Tracker
// +----------------------------------------------------------------------+
// | Copyright (c) Anuko International Ltd. (http://www.anuko.com)
// +----------------------------------------------------------------------+
// | LIBERAL FREEWARE LICENSE: This source code document may be used
// | by anyone for any purpose, and freely redistributed alone or in
// | combination with other software, provided that the license is obeyed.
// |
// | There are only two ways to violate the license:
// |
// | 1. To redistribute this code in source form, with the copyright
// |    notice or license removed or altered. (Distributing in compiled
// |    forms without embedded copyright notices is permitted).
// |
// | 2. To redistribute modified versions of this code in *any* form
// |    that bears insufficient indications that the modifications are
// |    not the work of the original author(s).
// |
// | This license applies to this document only, not any other software
// | that it may be combined with.
// |
// +----------------------------------------------------------------------+
// | Contributors:
// | http://www.anuko.com/time_tracker/credits.htm
// +----------------------------------------------------------------------+

require_once('initialize.php');
import('DateAndTime');
import('ttInvoiceHelper');
import('ttClientHelper');

// Authentication check and redirect.
if ($auth->isAuthenticated()) {
  if ($user->isAdmin()) {
    header('Location: admin_teams.php');
    exit();
  }
} else {
  header('Location: login.php');
  exit();
}

$invoice_id = (int)$request->getParameter('id');
$invoice = ttInvoiceHelper::getInvoice($invoice_id);
$invoice_date = new DateAndTime(DB_DATEFORMAT, $invoice['date']);
$client = ttClientHelper::getClient($invoice['client_id'], true);

$invoice_items = ttInvoiceHelper::getInvoiceItems($invoice_id);

$subtotal = 0;
foreach($invoice_items as $item)
  $subtotal += $item['cost'];
$discount_percent = $invoice['discount'];
$discount = $subtotal * $discount_percent / 100;
$tax_percent = $client['tax'];
$tax = round(($subtotal - ($subtotal * $discount_percent / 100))* ($tax_percent / 100), 2);
$total = round(($subtotal - ($subtotal * $discount_percent / 100))* (1 + $tax_percent / 100), 2); 

$smarty->assign('subtotal', $user->currency.' '.str_replace('.', $i18n->getKey('format.float_delimiter'), sprintf('%8.2f', round($subtotal, 2))));
if ($discount > 0) {
  $smarty->assign('discount_percent', str_replace('.', $i18n->getKey('format.float_delimiter'), $discount_percent));
  $smarty->assign('discount', $user->currency.' '.str_replace('.', $i18n->getKey('format.float_delimiter'), sprintf('%8.2f', round($discount, 2))));
}
$smarty->assign('tax_percent', str_replace('.', $i18n->getKey('format.float_delimiter'), $tax_percent));
$smarty->assign('tax', $user->currency.' '.str_replace('.', $i18n->getKey('format.float_delimiter'), sprintf('%8.2f', round($tax, 2))));
$smarty->assign('total', $user->currency.' '.str_replace('.', $i18n->getKey('format.float_delimiter'), sprintf('%8.2f', round($total, 2))));

if ('.' != $i18n->getKey('format.float_delimiter')) {
  foreach ($invoice_items as &$item)
  	$item['cost'] = str_replace('.', $i18n->getKey('format.float_delimiter'), $item['cost']);
}

// Calculate colspan for invoice summary.
$colspan = 3;
if (MODE_PROJECTS == $user->tracking_mode)
  $colspan++;
else if (MODE_PROJECTS_AND_TASKS == $user->tracking_mode)
  $colspan += 2;

$smarty->assign('invoice_id', $invoice_id);
$smarty->assign('invoice_name', $invoice['name']);
$smarty->assign('invoice_date', $invoice_date->toString($user->date_format));
$smarty->assign('client_name', $client['name']);
$smarty->assign('client_address', $client['address']);
$smarty->assign('invoice_items', $invoice_items);
$smarty->assign('colspan', $colspan);
$smarty->assign('title', $i18n->getKey('title.view_invoice'));
$smarty->assign('content_page_name', 'invoice_view.tpl');
$smarty->display('index.tpl');	
?>